@@ -79,85 +79,6 @@ beta.glm <- function(model, x=TRUE, y=FALSE, skip=NULL, ...) {
 }
 
 
-#' @describeIn beta Standardized coefficients for a hierarchical linear model (nlme).
-#' @export
-beta.lme <- function(model, x=TRUE, y=TRUE, skip=NULL, ...) {
-    warning("The beta() function has been deprecated for multilevel models and is no longer
-supported. It will be removed in a future version. For more information on the
-reasons for this change, see the README on the package Github page here:
-https://github.com/jeff-hughes/reghelper")
-    
-    call <- model$call
-    vars <- names(model$data)
-    formula <- format(formula(model))
-    lhs <- attr(terms(model), 'response')  # index of criterion variable(s)
-    if (x == FALSE) {
-        vars <- vars[lhs]  # get only variables on left-hand side
-    }
-    if (y == FALSE) {
-        vars <- vars[-lhs]  # get only variables on right-hand side
-    }
-    
-    # cover special case, where all variables are skipped
-    if (length(vars) == 0) {
-        return(summary(model))
-    }
-    
-    formula <- .create_formula(model, vars, skip)
-    data <- formula[['data']]
-    call[['fixed']] <- as.formula(formula[['formula']])
-    call[['data']] <- quote(data)  # need this so data doesn't get output
-                                   # directly in the summary
-    return(summary(eval(call)))
-}
-
-
-#' @describeIn beta Standardized coefficients for a hierarchical linear model (lme4).
-#' @export
-beta.merMod <- function(model, x=TRUE, y=TRUE, skip=NULL, ...) {
-    warning("The beta() function has been deprecated for multilevel models and is no longer
-supported. It will be removed in a future version. For more information on the
-reasons for this change, see the README on the package Github page here:
-https://github.com/jeff-hughes/reghelper")
-    
-    call <- model@call
-    vars <- names(model@frame)
-    formula <- format(formula(model))
-    lhs <- attr(terms(model), 'response')  # index of criterion variable(s)
-    
-    # get all random variables, and unselect ones that are the DV
-    randvars <- unlist(as.list(attr(terms(model@frame), 'predvars.random')[-1]))
-    randvars <- randvars[-match(vars[lhs], randvars)]
-    randvars <- vars[match(randvars, vars)]
-        # turn variable symbols into character vector
-    
-    if (!is.null(skip)) {
-        skip <- union(skip, randvars)
-    } else {
-        skip <- randvars
-    }
-    
-    if (x == FALSE) {
-        vars <- vars[lhs]  # get only variables on left-hand side
-    }
-    if (y == FALSE) {
-        vars <- vars[-lhs]  # get only variables on right-hand side
-    }
-    
-    # cover special case, where all variables are skipped
-    if (length(vars) == 0) {
-        return(summary(model))
-    }
-    
-    formula <- .create_formula(model, vars, skip)
-    data <- formula[['data']]
-    call[['formula']] <- as.formula(formula[['formula']])
-    call[['data']] <- quote(data)  # need this so data doesn't get output
-                                   # directly in the summary
-    return(summary(eval(call)))
-}
-
-
 #' Create formula for standardized estimates.
 #' 
 #' Helper function creates a new formula and data with scales variables.
